@@ -1,13 +1,13 @@
-"""Test :mod:`coordinax._utils`."""
+"""Test :mod:`coordinax.utils`."""
 
 from warnings import warn
 
 import pytest
 
-from coordinax._exceptions import IrreversibleDimensionChange
+from coordinax._src.vectors.exceptions import IrreversibleDimensionChange
 
 
 def test_warning_irreversibledimensionchange():
-    """Test :class:`IrreversibleDimensionChange`."""
+    """Test `IrreversibleDimensionChange`."""
     with pytest.warns(UserWarning, match="Irreversible dimension change"):
         warn("Irreversible dimension change", IrreversibleDimensionChange, stacklevel=2)
